@@ -52,11 +52,13 @@ struct _IMSettingsProcPrivate {
 	IMSettingsInfo     *info;
 	IMSettingsProcInfo  main;
 	IMSettingsProcInfo  aux;
+	gchar              *desktop;
 	gboolean            shutdown:1;
 };
 enum {
 	PROP_0,
 	PROP_INFO,
+	PROP_DESKTOP,
 	LAST_PROP
 };
 enum {
@@ -316,6 +318,7 @@ _start_process(IMSettingsProc     *proc,
 			"GTK_IM_MODULE",
 			"QT_IM_MODULE",
 			"XMODIFIERS",
+			"XDG_CURRENT_DESKTOP",
 			NULL
 		};
 		gsize len, i, j, k;
@@ -353,6 +356,7 @@ _start_process(IMSettingsProc     *proc,
 		envp[j++] = g_strdup_printf("GTK_IM_MODULE=%s", gtkimm);
 		envp[j++] = g_strdup_printf("QT_IM_MODULE=%s", qtimm);
 		envp[j++] = g_strdup_printf("XMODIFIERS=@im=%s", xim);
+		envp[j++] = g_strdup_printf("XDG_CURRENT_DESKTOP=%s", priv->desktop);
 		envp[j++] = NULL;
 
 		cmd = g_strdup_printf("%s %s", prog_name, (prog_args ? prog_args : ""));
@@ -482,6 +486,10 @@ imsettings_proc_set_property(GObject      *object,
 	    case PROP_INFO:
 		    priv->info = g_value_dup_object(value);
 		    break;
+	    case PROP_DESKTOP:
+		    g_free(priv->desktop);
+		    priv->desktop = g_strdup(g_value_get_string(value));
+		    break;
 	    default:
 		    G_OBJECT_WARN_INVALID_PROPERTY_ID (object, prop_id, pspec);
 		    break;
@@ -501,6 +509,9 @@ imsettings_proc_get_property(GObject    *object,
 	    case PROP_INFO:
 		    g_value_set_object(value, priv->info);
 		    break;
+	    case PROP_DESKTOP:
+		    g_value_set_string(value, priv->desktop);
+		    break;
 	    default:
 		    G_OBJECT_WARN_INVALID_PROPERTY_ID (object, prop_id, pspec);
 		    break;
@@ -567,6 +578,12 @@ imsettings_proc_class_init(IMSettingsProcClass *klass)
 							    _("A GObject to be a IMSettingsInfo"),
 							    IMSETTINGS_TYPE_INFO,
 							    G_PARAM_READWRITE|G_PARAM_CONSTRUCT));
+	g_object_class_install_property(object_class, PROP_DESKTOP,
+					g_param_spec_string("desktop",
+							    _("Desktop name"),
+							    _("A desktop name for client"),
+							    NULL,
+							    G_PARAM_READWRITE));
 
 	/* signals */
 
